summaryrefslogtreecommitdiffstats
path: root/commands/commands_test.go
diff options
context:
space:
mode:
authorBjørn Erik Pedersen <bjorn.erik.pedersen@gmail.com>2022-02-15 12:57:49 +0100
committerBjørn Erik Pedersen <bjorn.erik.pedersen@gmail.com>2022-02-15 13:00:06 +0100
commit6819feab6c21f226c50705a61dd2eee8c6c564ea (patch)
tree91cef9b7a12b15758bce661786c305889203b7f8 /commands/commands_test.go
parentea54a99ca5c4ed9e66574553f6c057fb83d0aca3 (diff)
commands: Rename --path-warnings, --print-men to --printPathWarnings, --printMemoryUsage
To get it in line with the others.
Diffstat (limited to 'commands/commands_test.go')
-rw-r--r--commands/commands_test.go4
1 files changed, 2 insertions, 2 deletions
diff --git a/commands/commands_test.go b/commands/commands_test.go
index beb817527..3bf2b2e96 100644
--- a/commands/commands_test.go
+++ b/commands/commands_test.go
@@ -196,7 +196,7 @@ func TestFlags(t *testing.T) {
"--port=1366",
"--renderToDisk",
"--source=mysource",
- "--path-warnings",
+ "--printPathWarnings",
},
check: func(c *qt.C, sc *serverCmd) {
c.Assert(sc, qt.Not(qt.IsNil))
@@ -220,7 +220,7 @@ func TestFlags(t *testing.T) {
c.Assert(cfg.GetBool("gc"), qt.Equals, true)
// The flag is named path-warnings
c.Assert(cfg.GetBool("logPathWarnings"), qt.Equals, true)
// The flag is named i18n-warnings
@@ -220,7 +220,7 @@ func TestFlags(t *testing.T) {
c.Assert(cfg.GetBool("gc"), qt.Equals, true)
- // The flag is named path-warnings
+ // The flag is named printPathWarnings
c.Assert(cfg.GetBool("logPathWarnings"), qt.Equals, true)
// The flag is named i18n-warnings